@@ -23,7 +23,9 @@
 #include <sys/types.h>
 #include <time.h>
 
-#ifndef WIN32
+#ifdef WIN32
+#include <io.h>
+#else
 #include <unistd.h>
 #endif
 
