@@ -278,8 +278,10 @@ scrollback_load (session *sess)
 	int lines;
 
 #ifdef WIN32
+#if 0
 	char *cleaned_text;
 	int cleaned_len;
+#endif
 #else
 	char *map, *end_map;
 	struct stat statbuf;
@@ -385,6 +387,7 @@ scrollback_load (session *sess)
 				{
 					text = strip_color (text + 1, -1, STRIP_COLOR);
 				}
+#if 0
 				cleaned_text = text_replace_non_bmp (text, -1, &cleaned_len);
 				if (cleaned_text != NULL)
 				{
@@ -394,6 +397,8 @@ scrollback_load (session *sess)
 					}
 					text = cleaned_text;
 				}
+#endif
+				text_replace_non_bmp2 (text);
 				fe_print_text (sess, text, stamp);
 				if (prefs.text_stripcolor_replay)
 				{
@@ -925,6 +930,7 @@ iso_8859_1_to_utf8 (unsigned char *text, int len, gsize *bytes_written)
 #ifdef WIN32
 /* replace characters outside of the Basic Multilingual Plane with
  * replacement characters (0xFFFD) */
+#if 0
 char *
 text_replace_non_bmp (char *utf8_input, int input_length, glong *output_length)
 {
@@ -962,6 +968,30 @@ text_replace_non_bmp (char *utf8_input, int input_length, glong *output_length)
 }
 #endif
 
+void
+text_replace_non_bmp2 (char *utf8_input)
+{
+	char *tmp = utf8_input, *next;
+	gunichar suspect;
+
+	while (tmp != NULL && *tmp)
+	{
+		next = g_utf8_next_char(tmp);
+		suspect = g_utf8_get_char_validated(tmp, next - tmp);
+		if ((suspect >= 0x1D173 && suspect <= 0x1D17A) || (suspect >= 0xE0001 && suspect <= 0xE007F))
+		{
+			/* 0xFFFD - replacement character */
+			*tmp = 0xEF;
+			*(++tmp) = 0xBF;
+			*(++tmp) = 0xBD;
+			*(++tmp) = 0x1A;	/* ASCII Sub to fill the 4th non-BMP byte */
+		}
+
+		tmp = next;
+	}
+}
+#endif
+
 char *
 text_validate (char **text, int *len)
 {
@@ -2173,9 +2203,9 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 	case XP_TE_DPRIVMSG:
 	case XP_TE_PRIVACTION:
 	case XP_TE_DPRIVACTION:
-		if (chanopt_is_set_a (prefs.input_beep_priv, sess->alert_beep))
+		if (chanopt_is_set_a (prefs.input_beep_priv, sess->alert_beep) && !prefs.away_omit_alerts)
 			sound_beep (sess);
-		if (chanopt_is_set_a (prefs.input_flash_priv, sess->alert_taskbar))
+		if (chanopt_is_set_a (prefs.input_flash_priv, sess->alert_taskbar) && !prefs.away_omit_alerts)
 			fe_flash_window (sess);
 		/* why is this one different? because of plugin-tray.c's hooks! ugly */
 		if (sess->alert_tray == SET_ON)
@@ -2185,9 +2215,9 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 	/* ===Highlighted message=== */
 	case XP_TE_HCHANACTION:
 	case XP_TE_HCHANMSG:
-		if (chanopt_is_set_a (prefs.input_beep_hilight, sess->alert_beep))
+		if (chanopt_is_set_a (prefs.input_beep_hilight, sess->alert_beep) && !prefs.away_omit_alerts)
 			sound_beep (sess);
-		if (chanopt_is_set_a (prefs.input_flash_hilight, sess->alert_taskbar))
+		if (chanopt_is_set_a (prefs.input_flash_hilight, sess->alert_taskbar) && !prefs.away_omit_alerts)
 			fe_flash_window (sess);
 		if (sess->alert_tray == SET_ON)
 			fe_tray_set_icon (FE_ICON_MESSAGE);
@@ -2196,9 +2226,9 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 	/* ===Channel message=== */
 	case XP_TE_CHANACTION:
 	case XP_TE_CHANMSG:
-		if (chanopt_is_set_a (prefs.input_beep_chans, sess->alert_beep))
+		if (chanopt_is_set_a (prefs.input_beep_chans, sess->alert_beep) && !prefs.away_omit_alerts)
 			sound_beep (sess);
-		if (chanopt_is_set_a (prefs.input_flash_chans, sess->alert_taskbar))
+		if (chanopt_is_set_a (prefs.input_flash_chans, sess->alert_taskbar) && !prefs.away_omit_alerts)
 			fe_flash_window (sess);
 		if (sess->alert_tray == SET_ON)
 			fe_tray_set_icon (FE_ICON_MESSAGE);
