@@ -156,6 +156,7 @@ struct xchatprefs
 
 	int away_timeout;
 	int away_size_max;
+	int away_omit_alerts;
 
 	int gui_pane_left_size;
 	int gui_pane_right_size;
@@ -204,13 +205,12 @@ struct xchatprefs
 	char dcc_ip_str[DOMAINLEN + 1];
 
 	unsigned int tab_small;
+	unsigned int tab_icons;
 	unsigned int tab_sort;
 	unsigned int mainwindow_save;
 	unsigned int perc_color;
 	unsigned int perc_ascii;
-	unsigned int autosave;
 	unsigned int autodialog;
-	unsigned int autosave_url;
 	unsigned int autoreconnect;
 	unsigned int autoreconnectonfail;
 	unsigned int invisible;
@@ -313,7 +313,6 @@ struct xchatprefs
 #ifdef WIN32
 	unsigned int identd;
 	unsigned int emoticons;
-	unsigned int tab_icons;
 #endif
 
 	unsigned int ctcp_number_limit;	/*flood */
@@ -324,6 +323,7 @@ struct xchatprefs
 
 	unsigned int url_grabber;
 	unsigned int url_grabber_limit;
+	unsigned int url_logging;
 	/* Tells us if we need to save, only when they've been edited.
 		This is so that we continue using internal defaults (which can
 		change in the next release) until the user edits them. */
