@@ -138,7 +138,9 @@ static void
 url_save_callback (void *arg1, char *file)
 {
 	if (file)
-		url_save (file, "w", TRUE);
+	{
+		url_save_tree (file, "w", TRUE);
+	}
 }
 
 static void
